Plots of cross validation results as a function of lambda.
cv_plots(model, logLambda = TRUE, loi = NULL, ...)returns a cross validation plot
A cv.rq.pen() object.
Whether lambda values should be logged or not.
Lambda indexes of interest, if null all lambda values will be used.
Additional parameters sent to plot function.
Ben Sherwood, ben.sherwood@ku.edu